@@ -7,8 +7,8 @@ afsroot='/afs'
 alignbytes='8'
 ansi2knr=''
 aphostname='/bin/hostname'
-archlib='/usr/local/lib/perl5/5.23/unknown'
-archlibexp='/usr/local/lib/perl5/5.23/unknown'
+archlib='/usr/local/lib/perl5/5.25/unknown'
+archlibexp='/usr/local/lib/perl5/5.25/unknown'
 archname='unknown64'
 asctime_r_proto='0'
 bin='/usr/local/bin'
@@ -172,6 +172,7 @@ d_fsync='undef'
 d_ftello='undef'
 d_ftime='undef'
 d_futimes='undef'
+d_gai_strerror='undef'
 d_gdbm_ndbm_h_uses_prototypes='undef'
 d_gdbmndbm_h_uses_prototypes='undef'
 d_getaddrinfo='undef'
@@ -302,6 +303,7 @@ d_mbtowc='undef'
 d_memchr='define'
 d_memcmp='define'
 d_memcpy='define'
+d_memmem='undef'
 d_memmove='undef'
 d_memset='define'
 d_mkdir='undef'
@@ -371,6 +373,7 @@ d_pwpasswd='undef'
 d_pwquota='undef'
 d_qgcvt='undef'
 d_quad='define'
+d_querylocale='undef'
 d_random_r='undef'
 d_readdir64_r='undef'
 d_readdir='define'
@@ -487,6 +490,7 @@ d_strcoll='undef'
 d_strctcpy='undef'
 d_strerrm='strerror(e)'
 d_strerror='undef'
+d_strerror_l='undef'
 d_strerror_r='undef'
 d_strftime='undef'
 d_strlcat='undef'
@@ -710,6 +714,7 @@ i_values='undef'
 i_varargs='undef'
 i_varhdr='stdarg.h'
 i_vfork='undef'
+i_xlocale='undef'
 ignore_versioned_solibs='y'
 inc_version_list_init='NULL'
 installstyle='lib/perl5'
@@ -764,8 +769,8 @@ package='perl5'
 perl_static_inline='static'
 phostname='hostname'
 pidtype=int
-privlib='/usr/local/lib/perl5/5.23'
-privlibexp='/usr/local/lib/perl5/5.23'
+privlib='/usr/local/lib/perl5/5.25'
+privlibexp='/usr/local/lib/perl5/5.25'
 procselfexe=''
 prototype='undef'
 ptrsize='8'
@@ -815,11 +820,11 @@ sig_name_init='0'
 sig_num_init='0'
 sig_size='1'
 signal_t=int
-sitearch='/usr/local/lib/perl5/5.23/unknown'
-sitearchexp='/usr/local/lib/perl5/5.23/unknown'
-sitelib='/usr/local/lib/perl5/5.23'
+sitearch='/usr/local/lib/perl5/5.25/unknown'
+sitearchexp='/usr/local/lib/perl5/5.25/unknown'
+sitelib='/usr/local/lib/perl5/5.25'
 sitelib_stem='/usr/local/lib/perl5'
-sitelibexp='/usr/local/lib/perl5/5.23'
+sitelibexp='/usr/local/lib/perl5/5.25'
 sizesize=4
 sizetype='size_t'
 socksizetype='int'
